You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@cloudstack.apache.org by mc...@apache.org on 2014/03/14 00:55:14 UTC

[21/50] [abbrv] git commit: updated refs/heads/master to 8ff9460

Renaming acl to iam in the upgrade code


Project: http://git-wip-us.apache.org/repos/asf/cloudstack/repo
Commit: http://git-wip-us.apache.org/repos/asf/cloudstack/commit/bf479e75
Tree: http://git-wip-us.apache.org/repos/asf/cloudstack/tree/bf479e75
Diff: http://git-wip-us.apache.org/repos/asf/cloudstack/diff/bf479e75

Branch: refs/heads/master
Commit: bf479e75ca608c84631fe5e37e61df18b6ad7ac0
Parents: 9f47466
Author: Prachi Damle <pr...@cloud.com>
Authored: Wed Feb 26 17:55:48 2014 -0800
Committer: Prachi Damle <pr...@cloud.com>
Committed: Wed Feb 26 17:56:38 2014 -0800

----------------------------------------------------------------------
 .../src/com/cloud/upgrade/dao/Upgrade430to440.java  | 16 ++++++++--------
 1 file changed, 8 insertions(+), 8 deletions(-)
----------------------------------------------------------------------


http://git-wip-us.apache.org/repos/asf/cloudstack/blob/bf479e75/engine/schema/src/com/cloud/upgrade/dao/Upgrade430to440.java
----------------------------------------------------------------------
diff --git a/engine/schema/src/com/cloud/upgrade/dao/Upgrade430to440.java b/engine/schema/src/com/cloud/upgrade/dao/Upgrade430to440.java
index dc89a15..dcf810e 100644
--- a/engine/schema/src/com/cloud/upgrade/dao/Upgrade430to440.java
+++ b/engine/schema/src/com/cloud/upgrade/dao/Upgrade430to440.java
@@ -59,20 +59,20 @@ public class Upgrade430to440 implements DbUpgrade {
 
     @Override
     public void performDataMigration(Connection conn) {
-        populateACLGroupAccountMap(conn);
+        populateIAMGroupAccountMap(conn);
         secondaryIpsAccountAndDomainIdsUpdate(conn);
     }
 
-    // populate acl_group_account_map table for existing accounts
-    private void populateACLGroupAccountMap(Connection conn) {
+    // populate iam_group_account_map table for existing accounts
+    private void populateIAMGroupAccountMap(Connection conn) {
         PreparedStatement acctInsert = null;
         PreparedStatement acctQuery = null;
         ResultSet rs = null;
 
-        s_logger.debug("Populating acl_group_account_map table for existing accounts...");
+        s_logger.debug("Populating iam_group_account_map table for existing accounts...");
         try {
             acctInsert = conn
-                    .prepareStatement("INSERT INTO `cloud`.`acl_group_account_map` (group_id, account_id, created) values(?, ?, Now())");
+                    .prepareStatement("INSERT INTO `cloud`.`iam_group_account_map` (group_id, account_id, created) values(?, ?, Now())");
             acctQuery = conn
                     .prepareStatement("select id, type from `cloud`.`account` where removed is null");
             rs = acctQuery.executeQuery();
@@ -81,13 +81,13 @@ public class Upgrade430to440 implements DbUpgrade {
                 Long acct_id = rs.getLong("id");
                 short type = rs.getShort("type");
 
                 // insert entry in acl_group_account_map table
                 acctInsert.setLong(1, type + 1);
                 acctInsert.setLong(2, acct_id);
                 acctInsert.executeUpdate();
             }
         } catch (SQLException e) {
-            String msg = "Unable to populate acl_group_account_map for existing accounts." + e.getMessage();
+            String msg = "Unable to populate iam_group_account_map for existing accounts." + e.getMessage();
             s_logger.error(msg);
             throw new CloudRuntimeException(msg, e);
         } finally {
@@ -105,7 +105,7 @@ public class Upgrade430to440 implements DbUpgrade {
             } catch (SQLException e) {
             }
         }
-        s_logger.debug("Completed populate acl_group_account_map for existing accounts.");
+        s_logger.debug("Completed populate iam_group_account_map for existing accounts.");
     }
@@ -81,13 +81,13 @@ public class Upgrade430to440 implements DbUpgrade {
                 short type = rs.getShort("type");
 
-                // insert entry in acl_group_account_map table
+                // insert entry in iam_group_account_map table
                 acctInsert.setLong(1, type + 1);
                 acctInsert.setLong(2, acct_id);